#
# spec file for package quimup
#
# Copyright (c) 2016 Packman team: http://packman.links2linux.org/
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


Name:           quimup
Version:        1.4.1
Release:        1.11
Summary:        A client for the music player daemon (MPD)
License:        GPL-3.0+
Group:          Productivity/Multimedia/Sound/Players
Url:            http://www.coonsden.com/
Source0:        http://coonsden.com/dl0ads/quimup_%{version}_source.tar.gz
Source1:        %{name}.desktop
Patch0:         quimup-gcc47.patch

BuildRequires:  libmpdclient-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(taglib)
Requires:       mpd

%description
QUIMUP is a client for the music player daemon (MPD) written in C++ and QT3.

The program can be used with most Linux desktops (KDE, GNOME, XFCE) and is covered
by the General Public License: it is free and 'open source'.
The clean interface makes controlling MPD's many features easy and intuitive.
The focus is on mouse handling: playlist management is done entirely by drag-&-drop;
playback functions are directly accessible from the system tray.
Quimup turns MPD into a perfect desktop music player.

%prep
# we don't want a space in the path
%setup -c -T
tar -xzf %{SOURCE0} --strip-components=1
%patch0 -p1


%build
qmake-qt5 \
QMAKE_STRIP="" \
QMAKE_CFLAGS+="%{optflags}" \
QMAKE_CXXFLAGS+="%{optflags}" \
%{name}.pro

make %{?_smp_mflags}


%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
install -D -m 755 %{name} %{buildroot}/%{_bindir}/%{name}
install -D -m 644 %{SOURCE1} %{buildroot}/%{_datadir}/applications/%{name}.desktop
install -D -m 644 src/resources/mn_icon.png %{buildroot}/%{_datadir}/pixmaps/%{name}.png
%suse_update_desktop_file -r %{name} AudioVideo Player


%files
%defattr(-,root,root)
%doc COPYING changelog description FAQ.txt README
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png

%changelog
* Sun May 15 2016 dap.darkness@gmail.com
- Update to version 1.4.1:
  (note that 1.4.2 introduces build time issue against taglib)
  * Fixed: On startup player could show 2 close buttons.
  * Fixed: Folder browser did not list .m3u playlists
  * Coded: Added #include <QDataStream> to qtlocalpeer.h
  * Other: Minor changes in dialog text and command-line output.
  * Added: Use flac-type embedded cover art from ogg file.
- Removed quimup-1.4.0_qt5-5.5.patch.
* Mon Oct  5 2015 avvissu@yandex.ru
- Fix build on openSUSE > 13.2: quimup-1.4.0_qt5-5.5.patch
* Tue Mar 24 2015 aloisio@gmx.com
- update to version 1.4.0
  * Coded: Migrated the code to QT5
  * Fixed: After changing colors wrong album-art could be shown.
  * Added: Use embedded cover art from asf and ape-tagged mp3.
- spec cleanup
* Tue Jul  8 2014 dap.darkness@gmail.com
- new upstream version <1.3.2>
  * Fixed: Provided password was not used unconditionally.
  * Fixed: Playlist not updated when a dropped item was rejected.
  * Fixed: Settings were not saved upon system shutdown/logout.
  * Fixed: Could not find translation(s) in default location.
  * Fixed: Music dir was not always found automatically.
  * Added: Use embedded cover art (mp3 ogg mpc mp4 flac wv ape).
  * Added: Player and Browser now respond to 'media keys'.
  * Added: Support for *.cue playlist files in folder view.
  * Added: 'Reset status' to playlist context menu.
  * Added: '-l none' to cmd parameters to force internal locale.
  * Added: More extensions are accepted for D&D operations.
  * Other: Some cosmetic tweaks, as usual.
- added copyright&license header.
- removed clean section.
* Sat Dec 14 2013 dap.darkness@gmail.com
- new upstream version <1.3.1>
  * Added: Support for the 'Disc Number' tag.
  * Added: Stream loader can handle compound urls better.
  * Added: Manually override MPD's (remote) music dir.
  * Fixed: Crash upon calling mpd_return_pair (Archlinux).
  * Fixed: Player changed position after hide-show toggle.
  * Fixed: Allow more time to connect to MPD at start-up.
  * Fixed: Possible wrong sorting order of dragged items.
  * Coded: Project 'includes' libmpdclient using pkg-config.
* Sat Jan 12 2013 dap.darkness@gmail.com
- new upstream version <1.3.0>
  * Added: "Drag & drop" from file manager to quimup.
  * Added: "Open with" from file manager (%%U or %%F).
  * Added: Single-instance-mode (by default).
  * Added: Localization support (no translations yet).
  * Added: Command line parameters (try "quimup -help").
  * Added: Rescan tags for any selection (library menu).
  * Added: Folder search in the browser.
  * Added: Check if mpd is running when quimup starts up.
  * Added: Option to apply colors to the album info widget.
  * Added: Music directory is requested from MPD (0.17+).
  * Added: Playlist scrolls to drop-position after d&d.
  * Added: Drop on playlist allows insert (not just append).
  * Added: Manually controlled widths in library and playlist.
  * Added: Track titles shown across all colums in library.
  * Added: A first-run dialog with some useful tips.
  * Added: More details on command line in case of MPD-errors.
  * Lots of fixes and remakes.
- build changes
  * Mpd became required [#PM-66].
  * New program icon place.
  * Debuginfo was enabled.
* Sat May 19 2012 seife+obs@b1-systems.com
- fix build with gcc 4.7
* Wed Feb 23 2011 detlef@links2linux.de
- new upstream version <1.2.0>
  * Settings are now saved when applied (and on exit).
  * The volume slider is now always visible (was a pop-up).
  * The volume slider keeps the focus after a button click.
  * The progress bar is snappier (now based on QSlider).
  * "Modified" mode now sorts albums (rather than folders).
  * "Modified" now also possible when mpd runs remotely.
  * "Modified" now puts most recent item on top of the list.
  * "Modified" now handles missing tags correctly.
  * New library mode: Albums sorted by year (i.e. date tag).
  * Replaygain mode can now be set on the fly from Quimup.
  * Library and Playlist can be toggled to use full window.
  * Improved automatic column-width handling (i.m.h.o.).
  * "Reload audio tags" even when mod-time has not changed.
  * Fixed: 'Played' status was reset by "Reload audio tags".
  * Fixed: No response to 'disconnected' when in 'idle' mode.
  * "Collapse all" was added to the Library context menu.
  * Row colors now alternate in the library and playlist.
  * Tray icons were replaced (new and larger images).
  * Windows now always open normally (and never minimized).
  * Some minor cosmetic tweaks, as usual.
* Fri Jun 25 2010 detlef@links2linux.de
- new upstream version <1.1.1>
  * Volume slider now a pops up from the "status led".
  * Added volume control with mousewheel on "status led".
  * Playlist can now be rearranged (by drag & drop).
  * Added up/down keys to move through the playlist.
  * Added option to ignore leading 'the' when sorting artists.
  * "Start (mpd) with quimup" is now unchecked by default.
  * Added Ctrl-Q hotkey to close the player.
  * Fixed the "KDE logout was aborted by quimup" problem.
  * Year-tag format xxxx-xx-xx is now shown as xxxx only.
  * Empty year-tags are now ignored (prev. non-present only).
  * Fixed some typos.
  * Some cosmetic brush-ups, as usual.
* Sat May  8 2010 detlef@links2linux.de
- new upstream version <1.1.0>
* Sat Feb 21 2009 detlef@links2linux.de
- new upstream version <0.3.5>
  * Fixed: "KDE logout was cancelled by process quimup." (thanks Tilman Vogel)
  * Changed: Symlinks can now be used for album art (thanks Tilman Vogel)
  * Changed: Main MPD version is now shown as x.x (was the 'API' version x.x.x)
* Sat Jun 28 2008 detlef@links2linux.de
- new upstream version <0.3.4>
* Tue Feb 26 2008 detlef@links2linux.de
- new upstream version <0.3.3>
* Sat Jan 26 2008 detlef@links2linux.de
- new upstream version <0.3.2>
* Fri Nov 23 2007 detlef@links2linux.de
- new upstream version <0.3.1>
* Thu Oct 25 2007 detlef@links2linux.de
- initial build for packman
